#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ZERO_ELSE_ONE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ZERO_ELSE_ONE_HPP_INCLUDED

#include <nt2/boolean/include/functions/scalar/if_zero_else_one.hpp>

#endif
